@@ -21,9 +21,7 @@ KateSpellCheckManager::KateSpellCheckManager(QObject *parent)
 {
 }
 
-KateSpellCheckManager::~KateSpellCheckManager()
-{
-}
+KateSpellCheckManager::~KateSpellCheckManager() = default;
 
 QStringList KateSpellCheckManager::suggestions(const QString &word, const QString &dictionary)
 {
@@ -37,7 +35,7 @@ void KateSpellCheckManager::ignoreWord(const QString &word, const QString &dicti
     Sonnet::Speller speller;
     speller.setLanguage(dictionary);
     speller.addToSession(word);
-    emit wordIgnored(word);
+    Q_EMIT wordIgnored(word);
 }
 
 void KateSpellCheckManager::addToDictionary(const QString &word, const QString &dictionary)
@@ -45,7 +43,7 @@ void KateSpellCheckManager::addToDictionary(const QString &word, const QString &
     Sonnet::Speller speller;
     speller.setLanguage(dictionary);
     speller.addToPersonal(word);
-    emit wordAddedToDictionary(word);
+    Q_EMIT wordAddedToDictionary(word);
 }
 
 QList<KTextEditor::Range> KateSpellCheckManager::rangeDifference(const KTextEditor::Range &r1, const KTextEditor::Range &r2)
@@ -106,7 +104,11 @@ QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckLangu
     return toReturn;
 }
 
-QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckWrtHighlightingRanges(KTextEditor::DocumentPrivate *document, const KTextEditor::Range &range, const QString &dictionary, bool singleLine, bool returnSingleRange)
+QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckWrtHighlightingRanges(KTextEditor::DocumentPrivate *document,
+                                                                                                 const KTextEditor::Range &range,
+                                                                                                 const QString &dictionary,
+                                                                                                 bool singleLine,
+                                                                                                 bool returnSingleRange)
 {
     QList<QPair<KTextEditor::Range, QString>> toReturn;
     if (range.isEmpty()) {
@@ -195,7 +197,8 @@ QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckWrtHi
     return toReturn;
 }
 
-QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckRanges(KTextEditor::DocumentPrivate *doc, const KTextEditor::Range &range, bool singleLine)
+QList<QPair<KTextEditor::Range, QString>>
+KateSpellCheckManager::spellCheckRanges(KTextEditor::DocumentPrivate *doc, const KTextEditor::Range &range, bool singleLine)
 {
     QList<RangeDictionaryPair> toReturn;
     QList<RangeDictionaryPair> languageRangeList = spellCheckLanguageRanges(doc, range);
@@ -206,7 +209,9 @@ QList<QPair<KTextEditor::Range, QString>> KateSpellCheckManager::spellCheckRange
     return toReturn;
 }
 
-void KateSpellCheckManager::replaceCharactersEncodedIfNecessary(const QString &newWord, KTextEditor::DocumentPrivate *doc, const KTextEditor::Range &replacementRange)
+void KateSpellCheckManager::replaceCharactersEncodedIfNecessary(const QString &newWord,
+                                                                KTextEditor::DocumentPrivate *doc,
+                                                                const KTextEditor::Range &replacementRange)
 {
     const int attr = doc->kateTextLine(replacementRange.start().line())->attribute(replacementRange.start().column());
     if (!doc->highlight()->getCharacterEncodings(attr).isEmpty() && doc->containsCharacterEncoding(replacementRange)) {
@@ -247,7 +252,8 @@ void KateSpellCheckManager::trimRange(KTextEditor::DocumentPrivate *doc, KTextEd
         } else {
             cursor.setColumn(cursor.column() - 1);
         }
-        if (cursor.column() < doc->lineLength(cursor.line()) && !doc->characterAt(cursor).isSpace() && doc->characterAt(cursor).category() != QChar::Other_Control) {
+        if (cursor.column() < doc->lineLength(cursor.line()) && !doc->characterAt(cursor).isSpace()
+            && doc->characterAt(cursor).category() != QChar::Other_Control) {
             break;
         }
     } while (cursor > r.start());
